@@ -3,6 +3,7 @@ Implement the command-line tool interface for diff_quality.
 """
 
 import argparse
+import contextlib
 import io
 import logging
 import os
@@ -50,11 +51,13 @@ from diff_cover.violationsreporters.java_violations_reporter import (
     checkstyle_driver,
 )
 from diff_cover.violationsreporters.violations_reporter import (
+    ClangFormatDriver,
     CppcheckDriver,
     EslintDriver,
     PylintDriver,
     flake8_driver,
     jshint_driver,
+    mypy_driver,
     pycodestyle_driver,
     pydocstyle_driver,
     pyflakes_driver,
@@ -63,7 +66,9 @@ from diff_cover.violationsreporters.violations_reporter import (
 )
 
 QUALITY_DRIVERS = {
+    "clang": ClangFormatDriver(),
     "cppcheck": CppcheckDriver(),
+    "mypy": mypy_driver,
     "pycodestyle": pycodestyle_driver,
     "pyflakes": pyflakes_driver,
     "pylint": PylintDriver(),
@@ -79,8 +84,8 @@ QUALITY_DRIVERS = {
     "shellcheck": shellcheck_driver,
 }
 
-VIOLATION_CMD_HELP = "Which code quality tool to use (%s)" % "/".join(
-    sorted(QUALITY_DRIVERS)
+VIOLATION_CMD_HELP = (
+    f"Which code quality tool to use ({'/'.join(sorted(QUALITY_DRIVERS))})"
 )
 INPUT_REPORTS_HELP = "Which violations reports to use"
 OPTIONS_HELP = "Options to be passed to the violations tool"
@@ -313,20 +318,24 @@ def main(argv=None, directory=None):
         plugin_manager.add_hookspecs(hookspecs)
         plugin_manager.load_setuptools_entrypoints("diff_cover")
 
-        hooks = (
-            plugin_manager.hook.diff_cover_report_quality  # pylint: disable=no-member
-        )
+        hooks = plugin_manager.hook.diff_cover_report_quality
         for hookimpl in hooks.get_hookimpls():
             if hookimpl.plugin_name == tool:
                 reporter_factory_fn = hookimpl.function
                 break
 
-    if reporter or driver or reporter_factory_fn:
-        input_reports = []
+    # If none of the reporter, driver, or reporter_factory_fn are set
+    if not any((reporter, driver, reporter_factory_fn)):
+        LOGGER.error("Quality tool not recognized: '%s'", tool)
+        return 1
+
+    with contextlib.ExitStack() as stack:
         try:
+            input_reports = []
             for path in arg_dict["input_reports"]:
                 try:
-                    input_reports.append(open(path, "rb"))
+                    file_handle = stack.enter_context(open(path, "rb"))
+                    input_reports.append(file_handle)
                 except OSError:
                     LOGGER.error("Could not load report '%s'", path)
                     return 1
@@ -371,14 +380,6 @@ def main(argv=None, directory=None):
         except OSError as exc:
             LOGGER.error("Failure: '%s'", str(exc))
             return 1
-        # Close any reports we opened
-        finally:
-            for file_handle in input_reports:
-                file_handle.close()
-
-    else:
-        LOGGER.error("Quality tool not recognized: '%s'", tool)
-        return 1
 
 
 if __name__ == "__main__":
